@@ -124,12 +124,14 @@ typedef enum ViewKind{
 
 // NOTE: would like to use strchr(str, '\0') instead of this routine, but some buffers might not have a null terminator and stread by full to the the dt_size.
 static inline Py_UCS4*
-ucs4_get_end_p(Py_UCS4* p, Py_ssize_t dt_size) {
-    Py_UCS4* p_end = p + dt_size;
-    while (p < p_end && *p != '\0') {
-        p++;
+ucs4_get_end_p(Py_UCS4* p_start, Py_ssize_t dt_size) {
+    Py_UCS4* p;
+    for (p = p_start + dt_size - 1; p >= p_start; p--) {
+        if (*p != '\0') {
+            return p + 1; // return 1 more than the first non-null from the right
+        }
     }
-    return p;
+    return p; // p is equal to p_start
 }
 
 
